pm4py.evaluation package
========================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.evaluation.earth_mover_distance
   pm4py.evaluation.generalization
   pm4py.evaluation.precision
   pm4py.evaluation.replay_fitness
   pm4py.evaluation.simplicity
   pm4py.evaluation.soundness
   pm4py.evaluation.wf_net

Submodules
----------

pm4py.evaluation.evaluator module
---------------------------------

.. automodule:: pm4py.evaluation.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation
   :members:
   :undoc-members:
   :show-inheritance:
